|
From: <sv...@va...> - 2009-08-14 21:33:47
|
Author: sewardj
Date: 2009-08-14 22:33:34 +0100 (Fri, 14 Aug 2009)
New Revision: 10817
Log:
Double the maximum size of the conflict cache.
Modified:
trunk/helgrind/docs/hg-manual.xml
trunk/helgrind/hg_main.c
trunk/helgrind/libhb_core.c
Modified: trunk/helgrind/docs/hg-manual.xml
===================================================================
--- trunk/helgrind/docs/hg-manual.xml 2009-08-14 13:42:41 UTC (rev 10816)
+++ trunk/helgrind/docs/hg-manual.xml 2009-08-14 21:33:34 UTC (rev 10817)
@@ -1005,11 +1005,11 @@
conflicting access information is stored. If you find that
Helgrind is showing race errors with only one stack instead of
the expected two stacks, try increasing this value.</para>
- <para>The minimum value is 10,000 and the maximum is 10,000,000
- (ten times the default value). Increasing the value by 1
+ <para>The minimum value is 10,000 and the maximum is 20,000,000
+ (twenty times the default value). Increasing the value by 1
increases Helgrind's memory requirement by very roughly 100
- bytes, so the maximum value will easily eat up an extra
- gigabyte or so of memory.</para>
+ bytes, so the maximum value will easily eat up two extra
+ gigabytes or so of memory.</para>
</listitem>
</varlistentry>
Modified: trunk/helgrind/hg_main.c
===================================================================
--- trunk/helgrind/libhb_core.c 2009-08-14 13:42:41 UTC (rev 10816)
+++ trunk/helgrind/libhb_core.c 2009-08-14 21:33:34 UTC (rev 10817)
@@ -3797,7 +3797,7 @@
/* Check for sane command line params. Limit values must match
those in hg_process_cmd_line_option. */
tl_assert( HG_(clo_conflict_cache_size) >= 10*1000 );
- tl_assert( HG_(clo_conflict_cache_size) <= 10*1000*1000 );
+ tl_assert( HG_(clo_conflict_cache_size) <= 20*1000*1000 );
/* Check our counting is sane (expensive) */
if (CHECK_CEM)
|
--- trunk/helgrind/hg_main.c 2009-08-14 13:42:41 UTC (rev 10816)
+++ trunk/helgrind/hg_main.c 2009-08-14 21:33:34 UTC (rev 10817)
@@ -4397,10 +4397,10 @@
else if VG_XACT_CLO(arg, "--history-level=full",
HG_(clo_history_level), 2);
/* If you change the 10k/10mill limits, remember to also change
them in assertions at the top of event_map_maybe_GC. */
else if VG_BINT_CLO(arg, "--conflict-cache-size",
- HG_(clo_conflict_cache_size), 10*1000, 10*1000*1000) {}
+ HG_(clo_conflict_cache_size), 10*1000, 20*1000*1000) {}
/* "stuvwx" --> stuvwx (binary) */
else if VG_STR_CLO(arg, "--hg-sanity-flags", tmp_str) {
Modified: trunk/helgrind/libhb_core.c
@@ -4397,10 +4397,10 @@
else if VG_XACT_CLO(arg, "--history-level=full",
HG_(clo_history_level), 2);
- /* If you change the 10k/10mill limits, remember to also change
+ /* If you change the 10k/20mill limits, remember to also change
them in assertions at the top of event_map_maybe_GC. */
else if VG_BINT_CLO(arg, "--conflict-cache-size",
===================================================================